==> docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.31.2/luna-sdk_alma_rel_v.5.31.2/doc/fsdk/html/dir_96470401125dcf7b94020a7d1057712f.js <==
var dir_96470401125dcf7b94020a7d1057712f =
[
    [ "IAGSEstimator.h", "_i_a_g_s_estimator_8h_source.html", null ],
    [ "IAttributeEstimator.h", "_i_attribute_estimator_8h_source.html", null ],
    [ "IBackgroundEstimator.h", "_i_background_estimator_8h_source.html", null ],
    [ "IBestShotQualityEstimator.h", "_i_best_shot_quality_estimator_8h_source.html", null ],
    [ "IBlackWhiteEstimator.h", "_i_black_white_estimator_8h_source.html", null ],
    [ "ICredibilityCheckEstimator.h", "_i_credibility_check_estimator_8h_source.html", null ],
    [ "ICrowdEstimator.h", "_i_crowd_estimator_8h_source.html", null ],
    [ "IDeepFakeEstimator.h", "_i_deep_fake_estimator_8h_source.html", null ],
    [ "IDepthLivenessEstimator.h", "_i_depth_liveness_estimator_8h_source.html", null ],
    [ "IDynamicRangeEstimator.h", "_i_dynamic_range_estimator_8h_source.html", null ],
    [ "IEmotionsEstimator.h", "_i_emotions_estimator_8h_source.html", null ],
    [ "IEthnicityEstimator.h", "_i_ethnicity_estimator_8h_source.html", null ],
    [ "IEyeBrowEstimator.h", "_i_eye_brow_estimator_8h_source.html", null ],
    [ "IEyeEstimator.h", "_i_eye_estimator_8h_source.html", null ],
    [ "IFaceOcclusionEstimator.h", "_i_face_occlusion_estimator_8h_source.html", null ],
    [ "IFacialHairEstimator.h", "_i_facial_hair_estimator_8h_source.html", null ],
    [ "IFightsEstimator.h", "_i_fights_estimator_8h_source.html", null ],
    [ "IFishEyeEstimator.h", "_i_fish_eye_estimator_8h_source.html", null ],
    [ "IGazeEstimator.h", "_i_gaze_estimator_8h_source.html", null ],
    [ "IGlassesEstimator.h", "_i_glasses_estimator_8h_source.html", null ],
    [ "IHeadPoseEstimator.h", "_i_head_pose_estimator_8h_source.html", null ],
    [ "IHeadWearEstimator.h", "_i_head_wear_estimator_8h_source.html", null ],
    [ "IHumanAttributeEstimator.h", "_i_human_attribute_estimator_8h_source.html", null ],
    [ "IImageModificationEstimator.h", "_i_image_modification_estimator_8h_source.html", null ],
    [ "ILivenessDepthEstimator.h", "_i_liveness_depth_estimator_8h_source.html", null ],
    [ "ILivenessDepthRGBEstimator.h", "_i_liveness_depth_r_g_b_estimator_8h_source.html", null ],
    [ "ILivenessFlyingFacesEstimator.h", "_i_liveness_flying_faces_estimator_8h_source.html", null ],
    [ "ILivenessFPREstimator.h", "_i_liveness_f_p_r_estimator_8h_source.html", null ],
    [ "ILivenessIREstimator.h", "_i_liveness_i_r_estimator_8h_source.html", null ],
    [ "ILivenessOneShotRGBEstimator.h", "_i_liveness_one_shot_r_g_b_estimator_8h_source.html", null ],
    [ "ILivenessRGBMEstimator.h", "_i_liveness_r_g_b_m_estimator_8h_source.html", null ],
    [ "IMedicalMaskEstimator.h", "_i_medical_mask_estimator_8h_source.html", null ],
    [ "IMouthEstimator.h", "_i_mouth_estimator_8h_source.html", null ],
    [ "INaturalLightEstimator.h", "_i_natural_light_estimator_8h_source.html", null ],
    [ "INIRLivenessEstimator.h", "_i_n_i_r_liveness_estimator_8h_source.html", null ],
    [ "IOrientationEstimator.h", "_i_orientation_estimator_8h_source.html", null ],
    [ "IOverlapEstimator.h", "_i_overlap_estimator_8h_source.html", null ],
    [ "IPortraitStyle.h", "_i_portrait_style_8h_source.html", null ],
    [ "IPPEEstimator.h", "_i_p_p_e_estimator_8h_source.html", null ],
    [ "IQualityEstimator.h", "_i_quality_estimator_8h_source.html", null ],
    [ "IRedEyeEstimator.h", "_i_red_eye_estimator_8h_source.html", null ]
];

==> docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0.zip: docs_sdk_archive_luna-sdk_alma_rel_v.5.32.0/luna-sdk_alma_rel_v.5.32.0/doc/fsdk/html/dir_96470401125dcf7b94020a7d1057712f.js <==
var dir_96470401125dcf7b94020a7d1057712f =
[
    [ "IAGSEstimator.h", "_i_a_g_s_estimator_8h_source.html", null ],
    [ "IAttributeEstimator.h", "_i_attribute_estimator_8h_source.html", null ],
    [ "IBackgroundEstimator.h", "_i_background_estimator_8h_source.html", null ],
    [ "IBestShotQualityEstimator.h", "_i_best_shot_quality_estimator_8h_source.html", null ],
    [ "IBlackWhiteEstimator.h", "_i_black_white_estimator_8h_source.html", null ],
    [ "ICredibilityCheckEstimator.h", "_i_credibility_check_estimator_8h_source.html", null ],
    [ "ICrowdEstimator.h", "_i_crowd_estimator_8h_source.html", null ],
    [ "IDeepFakeEstimator.h", "_i_deep_fake_estimator_8h_source.html", null ],
    [ "IDepthLivenessEstimator.h", "_i_depth_liveness_estimator_8h_source.html", null ],
    [ "IDynamicRangeEstimator.h", "_i_dynamic_range_estimator_8h_source.html", null ],
    [ "IEmotionsEstimator.h", "_i_emotions_estimator_8h_source.html", null ],
    [ "IEthnicityEstimator.h", "_i_ethnicity_estimator_8h_source.html", null ],
    [ "IEyeBrowEstimator.h", "_i_eye_brow_estimator_8h_source.html", null ],
    [ "IEyeEstimator.h", "_i_eye_estimator_8h_source.html", null ],
    [ "IFaceOcclusionEstimator.h", "_i_face_occlusion_estimator_8h_source.html", null ],
    [ "IFacialHairEstimator.h", "_i_facial_hair_estimator_8h_source.html", null ],
    [ "IFightsEstimator.h", "_i_fights_estimator_8h_source.html", null ],
    [ "IFishEyeEstimator.h", "_i_fish_eye_estimator_8h_source.html", null ],
    [ "IGazeEstimator.h", "_i_gaze_estimator_8h_source.html", null ],
    [ "IGlassesEstimator.h", "_i_glasses_estimator_8h_source.html", null ],
    [ "IHeadPoseEstimator.h", "_i_head_pose_estimator_8h_source.html", null ],
    [ "IHeadWearEstimator.h", "_i_head_wear_estimator_8h_source.html", null ],
    [ "IHumanAttributeEstimator.h", "_i_human_attribute_estimator_8h_source.html", null ],
    [ "IImageModificationEstimator.h", "_i_image_modification_estimator_8h_source.html", null ],
    [ "ILivenessDepthEstimator.h", "_i_liveness_depth_estimator_8h_source.html", null ],
    [ "ILivenessDepthRGBEstimator.h", "_i_liveness_depth_r_g_b_estimator_8h_source.html", null ],
    [ "ILivenessFlyingFacesEstimator.h", "_i_liveness_flying_faces_estimator_8h_source.html", null ],
    [ "ILivenessOneShotRGBEstimator.h", "_i_liveness_one_shot_r_g_b_estimator_8h_source.html", null ],
    [ "ILivenessRGBMEstimator.h", "_i_liveness_r_g_b_m_estimator_8h_source.html", null ],
    [ "IMedicalMaskEstimator.h", "_i_medical_mask_estimator_8h_source.html", null ],
    [ "IMouthEstimator.h", "_i_mouth_estimator_8h_source.html", null ],
    [ "INaturalLightEstimator.h", "_i_natural_light_estimator_8h_source.html", null ],
    [ "INIRLivenessEstimator.h", "_i_n_i_r_liveness_estimator_8h_source.html", null ],
    [ "IOrientationEstimator.h", "_i_orientation_estimator_8h_source.html", null ],
    [ "IOverlapEstimator.h", "_i_overlap_estimator_8h_source.html", null ],
    [ "IPortraitStyle.h", "_i_portrait_style_8h_source.html", null ],
    [ "IPPEEstimator.h", "_i_p_p_e_estimator_8h_source.html", null ],
    [ "IQualityEstimator.h", "_i_quality_estimator_8h_source.html", null ],
    [ "IRedEyeEstimator.h", "_i_red_eye_estimator_8h_source.html", null ],
    [ "ISubjectiveQualityEstimator.h", "_i_subjective_quality_estimator_8h_source.html", null ]
];
